
From: Jan Harkes <jaharkes@cs.cmu.edu>

The patch below makes some needlessly global code static.

Signed-off-by: Adrian Bunk <bunk@stusta.de>
Signed-off-by: Jan Harkes <jaharkes@cs.cmu.edu>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/fs/coda/cnode.c           |    2 -
 25-akpm/fs/coda/dir.c             |    2 -
 25-akpm/fs/coda/file.c            |    2 -
 25-akpm/fs/coda/inode.c           |    2 -
 25-akpm/fs/coda/sysctl.c          |   56 +++++++++++++++++++-------------------
 25-akpm/include/linux/coda_proc.h |   21 --------------
 6 files changed, 33 insertions(+), 52 deletions(-)

diff -puN fs/coda/cnode.c~coda-make-global-code-static fs/coda/cnode.c
--- 25/fs/coda/cnode.c~coda-make-global-code-static	2005-01-10 17:29:40.846677280 -0800
+++ 25-akpm/fs/coda/cnode.c	2005-01-10 17:29:40.856675760 -0800
@@ -11,7 +11,7 @@
 #include <linux/coda_fs_i.h>
 #include <linux/coda_psdev.h>
 
-inline int coda_fideq(struct CodaFid *fid1, struct CodaFid *fid2)
+static inline int coda_fideq(struct CodaFid *fid1, struct CodaFid *fid2)
 {
 	return memcmp(fid1, fid2, sizeof(*fid1)) == 0;
 }
diff -puN fs/coda/dir.c~coda-make-global-code-static fs/coda/dir.c
--- 25/fs/coda/dir.c~coda-make-global-code-static	2005-01-10 17:29:40.847677128 -0800
+++ 25-akpm/fs/coda/dir.c	2005-01-10 17:29:40.857675608 -0800
@@ -55,7 +55,7 @@ int coda_fsync(struct file *, struct den
 
 int coda_hasmknod;
 
-struct dentry_operations coda_dentry_operations =
+static struct dentry_operations coda_dentry_operations =
 {
 	.d_revalidate	= coda_dentry_revalidate,
 	.d_delete	= coda_dentry_delete,
diff -puN fs/coda/file.c~coda-make-global-code-static fs/coda/file.c
--- 25/fs/coda/file.c~coda-make-global-code-static	2005-01-10 17:29:40.849676824 -0800
+++ 25-akpm/fs/coda/file.c	2005-01-10 17:29:40.857675608 -0800
@@ -26,7 +26,7 @@
 
 /* if CODA_STORE fails with EOPNOTSUPP, venus clearly doesn't support
  * CODA_STORE/CODA_RELEASE and we fall back on using the CODA_CLOSE upcall */
-int use_coda_close;
+static int use_coda_close;
 
 static ssize_t
 coda_file_read(struct file *coda_file, char __user *buf, size_t count, loff_t *ppos)
diff -puN fs/coda/inode.c~coda-make-global-code-static fs/coda/inode.c
--- 25/fs/coda/inode.c~coda-make-global-code-static	2005-01-10 17:29:40.850676672 -0800
+++ 25-akpm/fs/coda/inode.c	2005-01-10 17:29:40.858675456 -0800
@@ -89,7 +89,7 @@ static int coda_remount(struct super_blo
 }
 
 /* exported operations */
-struct super_operations coda_super_operations =
+static struct super_operations coda_super_operations =
 {
 	.alloc_inode	= coda_alloc_inode,
 	.destroy_inode	= coda_destroy_inode,
diff -puN fs/coda/sysctl.c~coda-make-global-code-static fs/coda/sysctl.c
--- 25/fs/coda/sysctl.c~coda-make-global-code-static	2005-01-10 17:29:40.852676368 -0800
+++ 25-akpm/fs/coda/sysctl.c	2005-01-10 17:29:40.858675456 -0800
@@ -41,35 +41,22 @@ static struct ctl_table_header *fs_table
 #define CODA_CACHE_INV 	 9       /* cache invalidation statistics */
 #define CODA_FAKE_STATFS 10	 /* don't query venus for actual cache usage */
 
-static ctl_table coda_table[] = {
- 	{CODA_TIMEOUT, "timeout", &coda_timeout, sizeof(int), 0644, NULL, &proc_dointvec},
- 	{CODA_HARD, "hard", &coda_hard, sizeof(int), 0644, NULL, &proc_dointvec},
- 	{CODA_VFS, "vfs_stats", NULL, 0, 0644, NULL, &do_reset_coda_vfs_stats},
- 	{CODA_CACHE_INV, "cache_inv_stats", NULL, 0, 0644, NULL, &do_reset_coda_cache_inv_stats},
- 	{CODA_FAKE_STATFS, "fake_statfs", &coda_fake_statfs, sizeof(int), 0600, NULL, &proc_dointvec},
-	{ 0 }
-};
-
-static ctl_table fs_table[] = {
-       {FS_CODA, "coda",    NULL, 0, 0555, coda_table},
-       {0}
-};
-
 struct coda_vfs_stats		coda_vfs_stat;
-struct coda_cache_inv_stats	coda_cache_inv_stat;
+static struct coda_cache_inv_stats	coda_cache_inv_stat;
 
-void reset_coda_vfs_stats( void )
+static void reset_coda_vfs_stats( void )
 {
 	memset( &coda_vfs_stat, 0, sizeof( coda_vfs_stat ) );
 }
 
-void reset_coda_cache_inv_stats( void )
+static void reset_coda_cache_inv_stats( void )
 {
 	memset( &coda_cache_inv_stat, 0, sizeof( coda_cache_inv_stat ) );
 }
 
-int do_reset_coda_vfs_stats( ctl_table * table, int write, struct file * filp,
-			     void __user * buffer, size_t * lenp, loff_t * ppos )
+static int do_reset_coda_vfs_stats( ctl_table * table, int write,
+				    struct file * filp, void __user * buffer,
+				    size_t * lenp, loff_t * ppos )
 {
 	if ( write ) {
 		reset_coda_vfs_stats();
@@ -82,9 +69,10 @@ int do_reset_coda_vfs_stats( ctl_table *
 	return 0;
 }
 
-int do_reset_coda_cache_inv_stats( ctl_table * table, int write, 
-				   struct file * filp, void __user * buffer, 
-				   size_t * lenp, loff_t * ppos )
+static int do_reset_coda_cache_inv_stats( ctl_table * table, int write,
+					  struct file * filp,
+					  void __user * buffer,
+					  size_t * lenp, loff_t * ppos )
 {
 	if ( write ) {
 		reset_coda_cache_inv_stats();
@@ -97,8 +85,8 @@ int do_reset_coda_cache_inv_stats( ctl_t
 	return 0;
 }
 
-int coda_vfs_stats_get_info( char * buffer, char ** start, off_t offset,
-			     int length)
+static int coda_vfs_stats_get_info( char * buffer, char ** start,
+				    off_t offset, int length)
 {
 	int len=0;
 	off_t begin;
@@ -158,8 +146,8 @@ int coda_vfs_stats_get_info( char * buff
 	return len;
 }
 
-int coda_cache_inv_stats_get_info( char * buffer, char ** start, off_t offset,
-				   int length)
+static int coda_cache_inv_stats_get_info( char * buffer, char ** start,
+					  off_t offset, int length)
 {
 	int len=0;
 	off_t begin;
@@ -196,6 +184,20 @@ int coda_cache_inv_stats_get_info( char 
 	return len;
 }
 
+static ctl_table coda_table[] = {
+ 	{CODA_TIMEOUT, "timeout", &coda_timeout, sizeof(int), 0644, NULL, &proc_dointvec},
+ 	{CODA_HARD, "hard", &coda_hard, sizeof(int), 0644, NULL, &proc_dointvec},
+ 	{CODA_VFS, "vfs_stats", NULL, 0, 0644, NULL, &do_reset_coda_vfs_stats},
+ 	{CODA_CACHE_INV, "cache_inv_stats", NULL, 0, 0644, NULL, &do_reset_coda_cache_inv_stats},
+ 	{CODA_FAKE_STATFS, "fake_statfs", &coda_fake_statfs, sizeof(int), 0600, NULL, &proc_dointvec},
+	{ 0 }
+};
+
+static ctl_table fs_table[] = {
+       {FS_CODA, "coda",    NULL, 0, 0555, coda_table},
+       {0}
+};
+
 
 #ifdef CONFIG_PROC_FS
 
@@ -207,7 +209,7 @@ int coda_cache_inv_stats_get_info( char 
 
 */
 
-struct proc_dir_entry* proc_fs_coda;
+static struct proc_dir_entry* proc_fs_coda;
 
 #endif
 
diff -puN include/linux/coda_proc.h~coda-make-global-code-static include/linux/coda_proc.h
--- 25/include/linux/coda_proc.h~coda-make-global-code-static	2005-01-10 17:29:40.853676216 -0800
+++ 25-akpm/include/linux/coda_proc.h	2005-01-10 17:29:40.859675304 -0800
@@ -72,26 +72,5 @@ struct coda_cache_inv_stats
 
 /* these global variables hold the actual statistics data */
 extern struct coda_vfs_stats		coda_vfs_stat;
-extern struct coda_cache_inv_stats	coda_cache_inv_stat;
-
-/* reset statistics to 0 */
-void reset_coda_vfs_stats( void );
-void reset_coda_cache_inv_stats( void );
-
-/* like coda_dointvec, these functions are to be registered in the ctl_table
- * data structure for /proc/sys/... files 
- */
-int do_reset_coda_vfs_stats( ctl_table * table, int write, struct file * filp,
-			     void __user * buffer, size_t * lenp, loff_t * ppos );
-int do_reset_coda_cache_inv_stats( ctl_table * table, int write, 
-				   struct file * filp, void __user * buffer, 
-				   size_t * lenp, loff_t * ppos );
-
-/* these functions are called to form the content of /proc/fs/coda/... files */
-int coda_vfs_stats_get_info( char * buffer, char ** start, off_t offset,
-			     int length);
-int coda_cache_inv_stats_get_info( char * buffer, char ** start, off_t offset,
-				   int length);
-
 
 #endif /* _CODA_PROC_H */
_
